@@ -5,6 +5,7 @@
 import logging
 from typing import *
 from simple_gl.gitlab_base import GitLabBase
+from code_analysis import CodeAnalysis
 
 
 class Commits(GitLabBase):
@@ -16,8 +17,8 @@ class Commits(GitLabBase):
         try:
             project = self.gl.projects.get(id=project_id)
             commit = project.commits.get(sha)
-            diff = commit.diff()
-            return diff
+            data = CodeAnalysis(datas=commit.diff())
+            return data.result()
         except Exception as e:
             logging.getLogger(__name__).error("Commits.get_code_diff.error: %s" % str(e))
             return False
